@@ -36,7 +36,7 @@ class LVMTemplateForm(NetBoxModelForm):
         help_text="Volume Group Name e.g. vg_docker",
     )
     size = FloatField(
-        label="Size (MB)",
+        label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -156,7 +156,7 @@ class LVMTemplateForm(NetBoxModelForm):
 #
 class DriveTemplateForm(NetBoxModelForm):
     size = FloatField(
-        label="Size (MB)",
+        label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -214,7 +214,7 @@ class DriveTemplateForm(NetBoxModelForm):
 
 class PartitionTemplateForm(NetBoxModelForm):
     size = FloatField(
-        label="Size (MB)",
+        label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -314,7 +314,7 @@ class VolumeSimpleForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
     size = FloatField(
-        label="Size (MB)",
+        label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
         required=False
