@@ -115,6 +115,8 @@ class Drive(NetBoxModel):
             super().delete(*args, **kwargs)
             for idx, tcd in enumerate(tcd_list):
                 tcd.drive.identifier = f'Hard Drive {idx + 1}'
+                print(f"New Identifier: {tcd.drive.identifier}")
+                tcd.drive.save()
         elif StorageConfigurationDrive.objects.filter(drive=self).count() > 0:
             scd = StorageConfigurationDrive.objects.get(drive=self)
             print(f"StorageConfigurationDriveObject: {scd}")
@@ -124,7 +126,7 @@ class Drive(NetBoxModel):
             for idx, scd in enumerate(scd_list):
                 scd.drive.identifier = f'Hard Drive {idx + 1}'
                 print(f"New Identifier: {scd.drive.identifier}")
-                scd.save()
+                scd.drive.save()
 
 
     def left_free_space(self):
