@@ -36,6 +36,13 @@ lv_menu_item = PluginMenuItem(
             ButtonColorChoices.GREEN,
             permissions=["netbox_storage.add_storage"],
         ),
+        PluginMenuButton(
+            "plugins:netbox_storage:logicalvolume_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_drive"],
+        ),
     ),
 )
 vg_menu_item = PluginMenuItem(
@@ -50,6 +57,13 @@ vg_menu_item = PluginMenuItem(
             ButtonColorChoices.GREEN,
             permissions=["netbox_storage.add_storage"],
         ),
+        PluginMenuButton(
+            "plugins:netbox_storage:volumegroup_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_drive"],
+        ),
     ),
 )
 pv_menu_item = PluginMenuItem(
